import {ClothingItem} from '../Products/Contracts/ClothingItem';

/**
 * Синглтон для управления каталогом продуктов.
 * Обеспечивает единую точку доступа к списку продуктов.
 */
export class ProductCatalogSingleton {
    private static instance: ProductCatalogSingleton; // Экземпляр синглтона
    private products: ClothingItem[] = []; // Список продуктов

    // Закрытый конструктор для предотвращения создания экземпляров извне
    private constructor() {
    }

    /**
     * Метод для получения единственного экземпляра ProductCatalogSingleton.
     * @returns {ProductCatalogSingleton} - Экземпляр синглтона.
     */
    public static getInstance(): ProductCatalogSingleton {
        if (!ProductCatalogSingleton.instance) {
            // Создает новый экземпляр, если он не существует.
            ProductCatalogSingleton.instance = new ProductCatalogSingleton();
        }
        // Возвращает экземпляр.
        return ProductCatalogSingleton.instance;
    }

    /**
     * Метод для добавления продукта в каталог.
     * @param product - Предмет одежды, который нужно добавить.
     */
    public addProduct(product: ClothingItem): void {
        // Добавляет продукт в массив.
        this.products.push(product);
    }

    /**
     * Метод для получения списка всех продуктов.
     * @returns {ClothingItem[]} - Массив предметов одежды.
     */
    public getProducts(): ClothingItem[] {
        // Возвращает массив продуктов.
        return this.products;
    }

    /**
     * Метод для очистки каталога продуктов.
     */
    public clearCatalog(): void {
        // Очищает массив продуктов.
        this.products = [];
    }
}
